[patch] iq2000: Fix comment typos.

Kazu Hirata kazu@cs.umass.edu
Sat Aug 23 02:59:00 GMT 2003


Hi,

Attached is a patch to fix comment typos.  Committed as obvious.

Kazu Hirata

2003-08-22  Kazu Hirata  <kazu@cs.umass.edu>

	* config/iq2000/iq2000.c: Fix comment typos.
	* config/iq2000/iq2000.md: Likewise.

Index: config/iq2000/iq2000.md
===================================================================
RCS file: /cvs/gcc/gcc/gcc/config/iq2000/iq2000.md,v
retrieving revision 1.2
diff -u -r1.2 iq2000.md
--- config/iq2000/iq2000.md	23 Aug 2003 01:32:54 -0000	1.2
+++ config/iq2000/iq2000.md	23 Aug 2003 02:57:46 -0000
@@ -1006,7 +1006,7 @@
 ;;	Different CC modes are used, based on what type of branch is
 ;;	done, so that we can constrain things appropriately.  There
 ;;	are assumptions in the rest of GCC that break if we fold the
-;;	operands into the branchs for integer operations, and use cc0
+;;	operands into the branches for integer operations, and use cc0
 ;;	for floating point, so we use the fp status register instead.
 ;;	If needed, an appropriate temporary is created to hold the
 ;;	of the integer compare.
@@ -1093,7 +1093,7 @@
   [(set_attr "type"	"branch")
    (set_attr "mode"	"none")])
 
-;; Conditional branch on equality comparision.
+;; Conditional branch on equality comparison.
 
 (define_insn "branch_equality"
   [(set (pc)



More information about the Gcc-patches mailing list
Index: config/iq2000/iq2000.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/config/iq2000/iq2000.c,v
retrieving revision 1.3
diff -u -r1.3 iq2000.c
--- config/iq2000/iq2000.c	23 Aug 2003 02:51:23 -0000	1.3
+++ config/iq2000/iq2000.c	23 Aug 2003 02:57:46 -0000
@@ -2697,7 +2697,7 @@
   /* The kind of comparison we are doing.  */
   enum rtx_code code = GET_CODE (operands[0]);
   /* Nonzero if the opcode for the comparison needs a `z' indicating
-     that it is a comparision against zero.  */
+     that it is a comparison against zero.  */
   int need_z_p;
   /* A string to use in the assembly output to represent the first
      operand.  */
@@ -2813,7 +2813,7 @@
 	char *c;
 
 	c = strchr (buffer, '\0');
 	/* Generate the reversed comparision.  This takes four
 	   bytes.  */
 	if (float_p)
 	  sprintf (c, "b%s\t%%Z2%s",
@@ -2813,7 +2813,7 @@
 
 	c = strchr (buffer, '\0');
-	/* Generate the reversed comparision.  This takes four
+	/* Generate the reversed comparison.  This takes four
 	   bytes.  */
 	if (float_p)